==> lnl-3.0.2.tar.gz: lnl-3.0.2/src/amenu-prot.h <==
/* amenu.c */

#ifdef __cplusplus
extern "C" {
#endif

void	init_auto_menu( void );
void	init_auto_mark_all_appoint( void );
void	init_auto_mark_appoint( long ls_mbr_n );
void	init_auto_mark_all_mbr( void );
void	init_auto_mark_mbr( long ls_mbr_n );
void	ver_up_auto_mark_1_0_4( long ls_mbr_n );
void	ver_up_auto_mark_1_1_1( long ls_mbr_n );
char	*menu_auto_mark( menu_t **pp, menu_t **dflt );
void	set_menu_auto_mark( menu_t **dflt );
char	*cb_menu_auto_mark_exec( menu_t **pp, menu_t **dflt );
void	set_auto_mark_cont( mbr_t *mbr );
bool_t	exec_menu_auto_mark( mbr_t *mbr );
bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr );
bool_t	exec_menu_auto_mark_item( mbr_t *mbr );
bool_t	exec_menu_auto_mark_door( mbr_t *mbr );
bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr );
char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_edit_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_trgt_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_trgt( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_dist_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_dist( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_act( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_cond_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_cond( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_appoint_item(
	menu_t **pp, menu_t **dflt
);
char	*set_menu_auto_mark_appoint_item(
	menu_t *ls, long *k, char mjr_key,
	auto_mark_appoint_item_t **apo
);
char	*cb_menu_auto_mark_appoint_item_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_appoint_item_mnr(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_macro( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_cont( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_copy_large( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_copy_small( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_arrange( menu_t **pp, menu_t **dflt );
char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_act( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr );
long	get_auto_mark_cur_n( void );
auto_mark_appoint_item_t	*get_auto_mark_appoint_item( mbr_t *mbr );
char	*get_msg_ttl_auto_mark( long n );
auto_mark_t	*get_ls_auto_mark( long ls_mbr_n );
auto_mark_appoint_item_t	*get_ls_auto_mark_appoint_item(
	long ls_mbr_n, long n
);

#ifdef __cplusplus
}
#endif

==> lnl-3.1.0.tar.gz: lnl-3.1.0/src/amenu-prot.h <==
/* amenu.c */

#ifdef __cplusplus
extern "C" {
#endif

void	init_auto_menu( void );
void	init_auto_mark_all_appoint( void );
void	init_auto_mark_appoint( long ls_mbr_n );
void	init_auto_mark_all_mbr( void );
void	init_auto_mark_mbr( long ls_mbr_n );
void	ver_up_auto_mark_1_0_4( long ls_mbr_n );
void	ver_up_auto_mark_1_1_1( long ls_mbr_n );
void	ver_up_auto_mark_1_1_3( void );
void	cv_msg_ttl_auto_mark( char *ttl );
char	*menu_auto_mark( menu_t **pp, menu_t **dflt );
void	set_menu_auto_mark( menu_t **dflt );
char	*cb_menu_auto_mark_exec( menu_t **pp, menu_t **dflt );
void	set_auto_mark_cont( mbr_t *mbr );
bool_t	exec_menu_auto_mark( mbr_t *mbr );
bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr );
bool_t	exec_menu_auto_mark_item( mbr_t *mbr );
bool_t	exec_menu_auto_mark_door( mbr_t *mbr );
bool_t	exec_menu_auto_mark_mbr( mbr_t *mbr );
char	*cb_menu_auto_mark_edit( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_edit_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_trgt_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_trgt( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_dist_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_dist( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_act( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_cond_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_cond( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_appoint_item(
	menu_t **pp, menu_t **dflt
);
char	*set_menu_auto_mark_appoint_item(
	menu_t *ls, long *k, char mjr_key,
	auto_mark_appoint_item_t **apo
);
char	*cb_menu_auto_mark_appoint_item_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_appoint_item_mnr(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_auto_mark_macro( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_cont( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_priority( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_copy_large( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_copy_small( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_arrange_top( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_mark_arrange_bottom( menu_t **pp, menu_t **dflt );
char	*menu_auto_mark_arrange( long n, long d );
char	*get_msg_menu_auto_mark_edit_trgt( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_dist( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_act( mbr_t *mbr );
char	*get_msg_menu_auto_mark_edit_cond( mbr_t *mbr );
long	get_auto_mark_cur_n( void );
auto_mark_appoint_item_t	*get_auto_mark_appoint_item( mbr_t *mbr );
char	*get_msg_ttl_auto_mark_code( long n );
char	*get_msg_ttl_auto_mark_name( long n );
char	*get_msg_ttl_auto_mark_info( long n );
char	*get_msg_ttl_auto_mark_hint( long n );
auto_mark_t	*get_ls_auto_mark( long ls_mbr_n );
auto_mark_appoint_item_t	*get_ls_auto_mark_appoint_item(
	long ls_mbr_n, long n
);

#ifdef __cplusplus
}
#endif
